import os
from pathlib import Path
import getpass
import shutil

username = getpass.getuser()
base = Path("/home/{}/.config/".format(username))
folder = Path("{}/djtodo".format(base))
file = Path("{}/djtodo/task.json".format(base))

def create_file():
    if not folder.is_dir():
            os.mkdir(folder)
    if not file.is_file(): 
            shutil.copy('task.json', file)
    





import sys
from File import create_file
import module

create_file()


def command(argument):
    if argument == "add":
        module.add()

    if argument == "list" or argument == "ls":
        module.ls()

    if argument == "remove":
        module.remove()

    if argument == "done":
        module.done()

def cli(args=None):
    
    if not args:
        argument = ""
        try:
            argument = sys.argv[1]
            command(argument)
        except IndexError:
            print("No argument")
            sys.exit()



import json
import sys
import File

argument = ""
try:
    argument = sys.argv[1]
except IndexError:
    pass
test= {}
data = {}
task_removed = []
new_data = []
reloaded_data = []
done_data = []

def reload_name():
    with open(File.file, "r") as f:
        dt = json.load(f)
    for items in dt:
        index = dt.index(items)
        items["name"] = index + 1
        reloaded_data.append(items)
    
    with open(File.file, "w") as f:
        json.dump(dt, f, indent=4)

def add():
    try:
        task = sys.argv[2]
    except IndexError:
        print("djtodo: empy argument")
        sys.exit()

    
    data = {'name': 0,'task': task, 'status': False}
    
    with open(File.file, "+r") as f:
        dt = json.load(f)
        dt.append(data)
        f.seek(0)
        json.dump(dt, f, indent=4)
    reload_name()

def ls():
    with open(File.file, "r", encoding='utf-8') as f:
        dt = json.load(f)
        for items in dt:
            if items["status"] == False:
                flag = "x"
                print("{} {} {}".format(flag, items["name"], items["task"]))
            else:
                flag = "o"
                print("{} {} {}".format(flag, items["name"], items["task"]))

def remove():
    try:
        name = sys.argv[2]
    except IndexError:
        print("djtodo: empy argument")
        sys.exit()
    
    with open(File.file, "r") as f:
        dt = json.load(f)

    for items in dt:
        if items["name"] != int(name):
            new_data.append(items)
            
    
    with open(File.file, "w") as f:
        json.dump(new_data, f, indent= 4)
    reload_name()

def done():
    try:
        status = sys.argv[2]
    except IndexError:
        print("djtodo: empy argument")
        sys.exit()
    
    with open(File.file, "r") as f:
        dt = json.load(f)
    
    for items in dt:
        if items["name"] == int(status):
            items["status"] = True
            done_data.append(items)
        else:
            done_data.append(items)
    
    with open(File.file, "w") as f:
        json.dump(done_data, f, indent=4)
        





# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['djtodo_cli', 'djtodo_cli.djtodo']

package_data = \
{'': ['*']}

modules = \
['File', 'module']
entry_points = \
{'console_scripts': ['djtodo-cli = djtodo_cli.djtodo.djtodo:cli']}

setup_kwargs = {
    'name': 'djtodo-cli',
    'version': '0.1.1',
    'description': '',
    'long_description': '# djtodo-cli\n\ndjtodo-cli is a CLI todo application.\n\n## Installation\n\nUse the package manager [pip](https://pip.pypa.io/en/stable/) to install djtodo-cli.\n\n```bash\npip install djtodo-cli\n```\n\n## Usage\n\n```add\ndjtodo-cli add <task>\n```\n>add task\n\n```list\ndjtodo-cli list\n```\n>print list of task\n\n```remove\ndjtodo-cli remove <number>\n```\n> remove task\n\n```done\ndjtodo-cli done <number>\n```\n>mark task as done\n \n  \n## Contributing\n\nPull requests are welcome. For major changes, please open an issue first\nto discuss what you would like to change.\n\nPlease make sure to update tests as appropriate.\n\n## License\n\n[MIT](https://choosealicense.com/licenses/mit/)\n\n\n\n',
    'author': 'Your Name',
    'author_email': 'you@example.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/dongjin2008/djtodo',
    'packages': packages,
    'package_data': package_data,
    'py_modules': modules,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
